==> activity-center-biz-1.1.3-20160719.030755-1-sources.jar: cn/com/duiba/activity/center/biz/service/hdtool/impl/DuibaHdtoolServiceImpl.java <==
package cn.com.duiba.activity.center.biz.service.hdtool.impl;

import cn.com.duiba.activity.center.api.dto.ActivityExtraInfoDto;
import cn.com.duiba.activity.center.api.dto.hdtool.DuibaHdtoolDto;
import cn.com.duiba.activity.center.api.dto.hdtool.DuibaHdtoolOptionsDto;
import cn.com.duiba.activity.center.api.dto.hdtool.HdtoolAppSpecifyDto;
import cn.com.duiba.activity.center.api.dto.quizz.AddActivityDto;
import cn.com.duiba.activity.center.biz.dao.DsConstants;
import cn.com.duiba.activity.center.biz.dao.hdtool.DuibaHdtoolDao;
import cn.com.duiba.activity.center.biz.entity.hdtool.DuibaHdtoolEntity;
import cn.com.duiba.activity.center.biz.entity.hdtool.DuibaHdtoolOptionsEntity;
import cn.com.duiba.activity.center.biz.entity.hdtool.HdtoolAppSpecifyEntity;
import cn.com.duiba.activity.center.biz.service.hdtool.DuibaHdtoolService;
import cn.com.duiba.activity.center.biz.support.CacheConstants;
import cn.com.duiba.wolf.cache.CacheClient;
import cn.com.duiba.wolf.cache.CacheLoader;
import cn.com.duiba.wolf.utils.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.TimeUnit;

/**
 * Created by wenqi.huang on 16/5/19.
 */
@Service
public class DuibaHdtoolServiceImpl implements DuibaHdtoolService {
    @Resource
    private DuibaHdtoolDao duibaHdtoolDao;
    @Resource
    private CacheClient cacheClient;

    private String getDuibaHdtoolCacheKeyById(Long id){
        return CacheConstants.KEY_DUIBA_HDTOOL_BY_ID + id;
    }

    private String getDuibaHdtoolOptionsCacheKeyById(Long id){
        return CacheConstants.KEY_DUIBA_HDTOOL_OPTIONS_BY_ID + id;
    }

    @Override
    public List<DuibaHdtoolDto> findAutoOff() {
        return BeanUtils.copyList(duibaHdtoolDao.findAutoOff(), DuibaHdtoolDto.class);
    }

    @Override
    public DuibaHdtoolDto find(final Long id) {
        return cacheClient.getWithCacheLoader(getDuibaHdtoolCacheKeyById(id), 5, TimeUnit.MINUTES, new CacheLoader<DuibaHdtoolDto>() {
            @Override
            public DuibaHdtoolDto load() {
                return BeanUtils.copy(duibaHdtoolDao.find(id), DuibaHdtoolDto.class);
            }
        });
    }

    @Override
    public List<DuibaHdtoolDto> findDuibaHdToolsList(Map<String, Object> paramMap) {
        return BeanUtils.copyList(duibaHdtoolDao.findDuibaHdToolsList(paramMap), DuibaHdtoolDto.class);
    }

    @Override
    public Integer countDuibaHdToolsList(Map<String, Object> queryMap) {
        return duibaHdtoolDao.countDuibaHdToolsList(queryMap);
    }

    @Override
    public List<AddActivityDto> findAllDuibaHdTools(Long appId) {
        return BeanUtils.copyList(duibaHdtoolDao.findAllDuibaHdTools(appId), AddActivityDto.class);
    }

    @Override
    public List<DuibaHdtoolDto> findAllByIds(List<Long> ids) {
        return BeanUtils.copyList(duibaHdtoolDao.findAllByIds(ids), DuibaHdtoolDto.class);
    }

    @Override
    public List<DuibaHdtoolOptionsDto> findOptionsByDuibaHdtoolId(Long hdtoolId) {
        return BeanUtils.copyList(duibaHdtoolDao.findOptionsByDuibaHdtoolId(hdtoolId), DuibaHdtoolOptionsDto.class);
    }

    public Map<Long, List<DuibaHdtoolOptionsDto>> findOptionsByDuibaHdtoolIds(List<Long> hdtoolIds){
        List<DuibaHdtoolOptionsEntity> list = duibaHdtoolDao.findOptionsByDuibaHdtoolIds(hdtoolIds);
        Map<Long, List<DuibaHdtoolOptionsDto>> map = new HashMap<>();
        for(DuibaHdtoolOptionsEntity e : list){
            List<DuibaHdtoolOptionsDto> innerList = map.get(e.getDuibaHdtoolId());
            if(innerList == null){
                innerList = new ArrayList<>();
                map.put(e.getDuibaHdtoolId(), innerList);
            }
            innerList.add(BeanUtils.copy(e, DuibaHdtoolOptionsDto.class));
        }

        return map;
    }

    @Override
    public Integer countOptionsByHdtoolId(Long hdtoolId) {
        return duibaHdtoolDao.countOptionsByHdtoolId(hdtoolId);
    }

    @Override
    public DuibaHdtoolOptionsDto findOptionById(final Long id) {
        return cacheClient.getWithCacheLoader(getDuibaHdtoolOptionsCacheKeyById(id), 30, TimeUnit.SECONDS, new CacheLoader<DuibaHdtoolOptionsDto>() {
            @Override
            public DuibaHdtoolOptionsDto load() {
                return BeanUtils.copy(duibaHdtoolDao.findOptionById(id), DuibaHdtoolOptionsDto.class);
            }
        });
    }

    @Override
    @Transactional(value= DsConstants.DATABASE_CREDITS)
    public DuibaHdtoolOptionsDto findOptionByIdForupdate(Long id) {
        return BeanUtils.copy(duibaHdtoolDao.findOptionByIdForupdate(id), DuibaHdtoolOptionsDto.class);
    }

    @Override
    public List<HdtoolAppSpecifyDto> findAllSpecifyByHdToolId(Long hdToolId) {
        return BeanUtils.copyList(duibaHdtoolDao.findAllSpecifyByHdToolId(hdToolId), HdtoolAppSpecifyDto.class);
    }

    @Override
    public HdtoolAppSpecifyDto findSpecifyByHdToolIdAndApp(Long duibaHdToolId, Long appId) {
        return BeanUtils.copy(duibaHdtoolDao.findSpecifyByHdToolIdAndApp(duibaHdToolId, appId), HdtoolAppSpecifyDto.class);
    }

    public Map<Long, HdtoolAppSpecifyDto> findSpecifyByHdToolIdsAndApp(List<Long> duibaHdToolIds, Long appId){
        List<HdtoolAppSpecifyEntity> list = duibaHdtoolDao.findSpecifyByHdToolIdsAndApp(duibaHdToolIds, appId);
        Map<Long, HdtoolAppSpecifyDto> map = new HashMap<>();
        for(HdtoolAppSpecifyEntity e : list){
            map.put(e.getDuibaHdtoolId(), BeanUtils.copy(e, HdtoolAppSpecifyDto.class));
        }

        return map;
    }

    @Override
    public HdtoolAppSpecifyDto findSpecifyById(Long id) {
        return BeanUtils.copy(duibaHdtoolDao.findSpecifyById(id), HdtoolAppSpecifyDto.class);
    }

    @Override
    public ActivityExtraInfoDto findExtraInfoById(Long id) {
        return BeanUtils.copy(duibaHdtoolDao.findExtraInfoById(id), ActivityExtraInfoDto.class);
    }

    @Override
    public List<Long> findHasUserdHdIds(Long itemId) {
        return duibaHdtoolDao.findHasUserdHdIds(itemId);
    }

    @Override
    public Long getCountDuibaHdTool(Map<String, Object> queryMap) {
        return duibaHdtoolDao.getCountDuibaHdTool(queryMap);
    }

    @Override
    public List<DuibaHdtoolDto> findDuibaToolList(Map<String, Object> queryMap) {
        return BeanUtils.copyList(duibaHdtoolDao.findDuibaToolList(queryMap), DuibaHdtoolDto.class);
    }

    @Override
    public int updateAutoOffDateNull(Long id) {
        int ret = duibaHdtoolDao.updateAutoOffDateNull(id);
        cacheClient.remove(getDuibaHdtoolCacheKeyById(id));
        return ret;
    }

    @Override
    public void insert(DuibaHdtoolDto duibaHdtoolDto) {
        DuibaHdtoolEntity e = BeanUtils.copy(duibaHdtoolDto, DuibaHdtoolEntity.class);
        duibaHdtoolDao.insert(e);
        duibaHdtoolDto.setId(e.getId());
    }

    @Override
    public int deleteById(Long id) {
        int ret = duibaHdtoolDao.deleteById(id);
        cacheClient.remove(getDuibaHdtoolCacheKeyById(id));
        return ret;
    }

    @Override
    public int update(DuibaHdtoolDto duibaHdtoolDto) {
        int ret = duibaHdtoolDao.update(BeanUtils.copy(duibaHdtoolDto, DuibaHdtoolEntity.class));
        cacheClient.remove(getDuibaHdtoolCacheKeyById(duibaHdtoolDto.getId()));
        return ret;
    }

    @Override
    public int updateStatus(Long id, Integer status) {
        int ret = duibaHdtoolDao.updateStatus(id, status);
        cacheClient.remove(getDuibaHdtoolCacheKeyById(id));
        return ret;
    }

    @Override
    public int decrementOptionRemaining(Long id) {
        int ret = duibaHdtoolDao.decrementOptionRemaining(id);
        cacheClient.remove(getDuibaHdtoolOptionsCacheKeyById(id));
        return ret;
    }

    @Override
    public int incrementOptionRemaining(Long id) {
        int ret = duibaHdtoolDao.incrementOptionRemaining(id);
        cacheClient.remove(getDuibaHdtoolOptionsCacheKeyById(id));
        return ret;
    }

    @Override
    public int deleteOptions(List<Long> ids) {
        if(ids == null || ids.isEmpty()){
            return 0;
        }
        int ret = duibaHdtoolDao.deleteOptions(ids);
        for(Long id:ids) {
            cacheClient.remove(getDuibaHdtoolOptionsCacheKeyById(id));
        }
        return ret;
    }

    @Override
    public int updateHdtoolPrize(DuibaHdtoolOptionsDto duibaHdToolOptionDO) {
        int ret = duibaHdtoolDao.updateHdtoolPrize(BeanUtils.copy(duibaHdToolOptionDO, DuibaHdtoolOptionsEntity.class));
        cacheClient.remove(getDuibaHdtoolOptionsCacheKeyById(duibaHdToolOptionDO.getId()));
        return ret;
    }

    @Override
    public void insertHdtoolOption(DuibaHdtoolOptionsDto duibaHdToolOptionDO) {
        DuibaHdtoolOptionsEntity e = BeanUtils.copy(duibaHdToolOptionDO, DuibaHdtoolOptionsEntity.class);
        duibaHdtoolDao.insertHdtoolOption(e);
        duibaHdToolOptionDO.setId(e.getId());
    }

    @Override
    public int updateHdtoolOption(DuibaHdtoolOptionsDto duibaHdToolOptionDO) {
        int ret = duibaHdtoolDao.updateHdtoolOption(BeanUtils.copy(duibaHdToolOptionDO, DuibaHdtoolOptionsEntity.class));
        cacheClient.remove(getDuibaHdtoolOptionsCacheKeyById(duibaHdToolOptionDO.getId()));
        return ret;
    }

    @Override
    public int deleteSpecifyById(Long id) {
        return duibaHdtoolDao.deleteSpecifyById(id);
    }

    @Override
    public void insertSpecify(HdtoolAppSpecifyDto hdtoolAppSpecifyDO) {
        HdtoolAppSpecifyEntity e = BeanUtils.copy(hdtoolAppSpecifyDO, HdtoolAppSpecifyEntity.class);
        duibaHdtoolDao.insertSpecify(e);
        hdtoolAppSpecifyDO.setId(e.getId());
    }

    @Override
	public int updateActivityCategory(long  duibaHdtoolId,long activityCategoryId){
    	int ret = duibaHdtoolDao.updateActivityCategory(duibaHdtoolId, activityCategoryId);
        cacheClient.remove(getDuibaHdtoolCacheKeyById(duibaHdtoolId));
        return ret;
    }
    
	/**
     * 根据ID查询标签
     */
    @Override
    public String findTag(Long id){
    	return duibaHdtoolDao.findTag(id);
    }
}

==> activity-center-biz-1.2.3.4-20160903.064458-1-sources.jar: cn/com/duiba/activity/center/biz/service/hdtool/impl/DuibaHdtoolServiceImpl.java <==
package cn.com.duiba.activity.center.biz.service.hdtool.impl;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.TimeUnit;

import javax.annotation.Resource;

import org.springframework.stereotype.Service;

import cn.com.duiba.activity.center.api.dto.ActivityExtraInfoDto;
import cn.com.duiba.activity.center.api.dto.hdtool.DuibaHdtoolDto;
import cn.com.duiba.activity.center.api.dto.hdtool.HdtoolAppSpecifyDto;
import cn.com.duiba.activity.center.api.dto.quizz.AddActivityDto;
import cn.com.duiba.activity.center.biz.dao.hdtool.DuibaHdtoolDao;
import cn.com.duiba.activity.center.biz.entity.hdtool.DuibaHdtoolEntity;
import cn.com.duiba.activity.center.biz.entity.hdtool.HdtoolAppSpecifyEntity;
import cn.com.duiba.activity.center.biz.service.hdtool.DuibaHdtoolService;
import cn.com.duiba.activity.center.biz.support.CacheConstants;
import cn.com.duiba.wolf.cache.CacheClient;
import cn.com.duiba.wolf.cache.CacheLoader;
import cn.com.duiba.wolf.utils.BeanUtils;

/**
 * Created by wenqi.huang on 16/5/19.
 */
@Service
public class DuibaHdtoolServiceImpl implements DuibaHdtoolService {
    @Resource
    private DuibaHdtoolDao duibaHdtoolDao;
    @Resource
    private CacheClient cacheClient;

    private String getDuibaHdtoolCacheKeyById(Long id){
        return CacheConstants.KEY_DUIBA_HDTOOL_BY_ID + id;
    }

    @Override
    public List<DuibaHdtoolDto> findAutoOff() {
        return BeanUtils.copyList(duibaHdtoolDao.findAutoOff(), DuibaHdtoolDto.class);
    }

    @Override
    public DuibaHdtoolDto find(final Long id) {
        return cacheClient.getWithCacheLoader(getDuibaHdtoolCacheKeyById(id), 5, TimeUnit.MINUTES, new CacheLoader<DuibaHdtoolDto>() {
            @Override
            public DuibaHdtoolDto load() {
                return BeanUtils.copy(duibaHdtoolDao.find(id), DuibaHdtoolDto.class);
            }
        });
    }

    @Override
    public List<DuibaHdtoolDto> findDuibaHdToolsList(Map<String, Object> paramMap) {
        return BeanUtils.copyList(duibaHdtoolDao.findDuibaHdToolsList(paramMap), DuibaHdtoolDto.class);
    }

    @Override
    public Integer countDuibaHdToolsList(Map<String, Object> queryMap) {
        return duibaHdtoolDao.countDuibaHdToolsList(queryMap);
    }

    @Override
    public List<AddActivityDto> findAllDuibaHdTools(Long appId) {
        return BeanUtils.copyList(duibaHdtoolDao.findAllDuibaHdTools(appId), AddActivityDto.class);
    }

    @Override
    public List<DuibaHdtoolDto> findAllByIds(List<Long> ids) {
        return BeanUtils.copyList(duibaHdtoolDao.findAllByIds(ids), DuibaHdtoolDto.class);
    }

    @Override
    public List<HdtoolAppSpecifyDto> findAllSpecifyByHdToolId(Long hdToolId) {
        return BeanUtils.copyList(duibaHdtoolDao.findAllSpecifyByHdToolId(hdToolId), HdtoolAppSpecifyDto.class);
    }

    @Override
    public HdtoolAppSpecifyDto findSpecifyByHdToolIdAndApp(Long duibaHdToolId, Long appId) {
        return BeanUtils.copy(duibaHdtoolDao.findSpecifyByHdToolIdAndApp(duibaHdToolId, appId), HdtoolAppSpecifyDto.class);
    }

    public Map<Long, HdtoolAppSpecifyDto> findSpecifyByHdToolIdsAndApp(List<Long> duibaHdToolIds, Long appId){
        List<HdtoolAppSpecifyEntity> list = duibaHdtoolDao.findSpecifyByHdToolIdsAndApp(duibaHdToolIds, appId);
        Map<Long, HdtoolAppSpecifyDto> map = new HashMap<>();
        for(HdtoolAppSpecifyEntity e : list){
            map.put(e.getDuibaHdtoolId(), BeanUtils.copy(e, HdtoolAppSpecifyDto.class));
        }

        return map;
    }

    @Override
    public HdtoolAppSpecifyDto findSpecifyById(Long id) {
        return BeanUtils.copy(duibaHdtoolDao.findSpecifyById(id), HdtoolAppSpecifyDto.class);
    }

    @Override
    public ActivityExtraInfoDto findExtraInfoById(Long id) {
        return BeanUtils.copy(duibaHdtoolDao.findExtraInfoById(id), ActivityExtraInfoDto.class);
    }

    @Override
    public Long getCountDuibaHdTool(Map<String, Object> queryMap) {
        return duibaHdtoolDao.getCountDuibaHdTool(queryMap);
    }

    @Override
    public List<DuibaHdtoolDto> findDuibaToolList(Map<String, Object> queryMap) {
        return BeanUtils.copyList(duibaHdtoolDao.findDuibaToolList(queryMap), DuibaHdtoolDto.class);
    }

    @Override
    public int updateAutoOffDateNull(Long id) {
        int ret = duibaHdtoolDao.updateAutoOffDateNull(id);
        cacheClient.remove(getDuibaHdtoolCacheKeyById(id));
        return ret;
    }

    @Override
    public void insert(DuibaHdtoolDto duibaHdtoolDto) {
        DuibaHdtoolEntity e = BeanUtils.copy(duibaHdtoolDto, DuibaHdtoolEntity.class);
        duibaHdtoolDao.insert(e);
        duibaHdtoolDto.setId(e.getId());
    }

    @Override
    public int deleteById(Long id) {
        int ret = duibaHdtoolDao.deleteById(id);
        cacheClient.remove(getDuibaHdtoolCacheKeyById(id));
        return ret;
    }

    @Override
    public int update(DuibaHdtoolDto duibaHdtoolDto) {
        int ret = duibaHdtoolDao.update(BeanUtils.copy(duibaHdtoolDto, DuibaHdtoolEntity.class));
        cacheClient.remove(getDuibaHdtoolCacheKeyById(duibaHdtoolDto.getId()));
        return ret;
    }

    @Override
    public int updateStatus(Long id, Integer status) {
        int ret = duibaHdtoolDao.updateStatus(id, status);
        cacheClient.remove(getDuibaHdtoolCacheKeyById(id));
        return ret;
    }

    @Override
    public int deleteSpecifyById(Long id) {
        return duibaHdtoolDao.deleteSpecifyById(id);
    }

    @Override
    public void insertSpecify(HdtoolAppSpecifyDto hdtoolAppSpecifyDO) {
        HdtoolAppSpecifyEntity e = BeanUtils.copy(hdtoolAppSpecifyDO, HdtoolAppSpecifyEntity.class);
        duibaHdtoolDao.insertSpecify(e);
        hdtoolAppSpecifyDO.setId(e.getId());
    }

    @Override
	public int updateActivityCategory(long  duibaHdtoolId,long activityCategoryId){
    	int ret = duibaHdtoolDao.updateActivityCategory(duibaHdtoolId, activityCategoryId);
        cacheClient.remove(getDuibaHdtoolCacheKeyById(duibaHdtoolId));
        return ret;
    }
    
	/**
     * 根据ID查询标签
     */
    @Override
    public String findTag(Long id){
    	return duibaHdtoolDao.findTag(id);
    }

	@Override
	public List<HdtoolAppSpecifyDto> findAllSpecifyMap(Map<String, Object> queryMap) {
		return BeanUtils.copyList(duibaHdtoolDao.findAllSpecifyMap(queryMap), HdtoolAppSpecifyDto.class);
	}

	@Override
	public Integer findAllSpecifyByCredordCount(Map<String, Object> queryMap) {
		return duibaHdtoolDao.findAllSpecifyByCredordCount(queryMap);
	}
}
